==> grafana-enterprise-8.4.5.darwin-amd64.tar.gz: grafana-8.4.5/public/app/angular/services/nav_model_srv.ts <==
import coreModule from 'app/angular/core_module';
import config from 'app/core/config';
import { find, isNumber } from 'lodash';
import { NavModel } from '@grafana/data';

export class NavModelSrv {
  navItems: any;

  constructor() {
    this.navItems = config.bootData.navTree;
  }

  getCfgNode() {
    return find(this.navItems, { id: 'cfg' });
  }

  getNav(...args: Array<string | number>) {
    let children = this.navItems;
    const nav = {
      breadcrumbs: [],
    } as any;

    for (const id of args) {
      // if its a number then it's the index to use for main
      if (isNumber(id)) {
        nav.main = nav.breadcrumbs[id];
        break;
      }

      const node: any = find(children, { id: id });
      nav.breadcrumbs.push(node);
      nav.node = node;
      nav.main = node;
      children = node.children;
    }

    if (nav.main.children) {
      for (const item of nav.main.children) {
        item.active = false;

        if (item.url === nav.node.url) {
          item.active = true;
        }
      }
    }

    return nav;
  }

  getNotFoundNav() {
    return getNotFoundNav(); // the exported function
  }
}

export function getExceptionNav(error: any): NavModel {
  console.error(error);
  return getWarningNav('Exception thrown', 'See console for details');
}

export function getNotFoundNav(): NavModel {
  return getWarningNav('Page not found', '404 Error');
}

export function getWarningNav(text: string, subTitle?: string): NavModel {
  const node = {
    text,
    subTitle,
    icon: 'exclamation-triangle',
  };
  return {
    breadcrumbs: [node],
    node: node,
    main: node,
  };
}

coreModule.service('navModelSrv', NavModelSrv);

==> grafana-enterprise-9.1.1.darwin-amd64.tar.gz: grafana-9.1.1/public/app/angular/services/nav_model_srv.ts <==
import { NavModel, NavModelItem } from '@grafana/data';
import coreModule from 'app/angular/core_module';
import config from 'app/core/config';

interface Nav {
  breadcrumbs: NavModelItem[];
  node?: NavModelItem;
  main?: NavModelItem;
}

export class NavModelSrv {
  navItems: NavModelItem[];

  constructor() {
    this.navItems = config.bootData.navTree;
  }

  getCfgNode() {
    return this.navItems.find((navItem) => navItem.id === 'cfg');
  }

  getNav(...args: Array<string | number>) {
    let children = this.navItems;
    const nav: Nav = {
      breadcrumbs: [],
    };

    for (const id of args) {
      // if its a number then it's the index to use for main
      if (typeof id === 'number') {
        nav.main = nav.breadcrumbs[id];
        break;
      }

      const node = children.find((child) => child.id === id);
      if (node) {
        nav.breadcrumbs.push(node);
        nav.node = node;
        nav.main = node;
        children = node.children ?? [];
      }
    }

    if (nav.main?.children) {
      for (const item of nav.main.children) {
        item.active = item.url === nav.node?.url;
      }
    }

    return nav;
  }

  getNotFoundNav() {
    return getNotFoundNav(); // the exported function
  }
}

export function getExceptionNav(error: any): NavModel {
  console.error(error);
  return getWarningNav('Exception thrown', 'See console for details');
}

export function getNotFoundNav(): NavModel {
  return getWarningNav('Page not found', '404 Error');
}

export function getWarningNav(text: string, subTitle?: string): NavModel {
  const node = {
    text,
    subTitle,
    icon: 'exclamation-triangle',
  };
  return {
    node: node,
    main: node,
  };
}

coreModule.service('navModelSrv', NavModelSrv);
